In-process transport
====================

See the :doc:`Python documentation <py-inproc>` for an overview of the
in-process transport.

.. doxygenclass:: spead2::inproc_queue
   :members: stop

Sending
-------

.. doxygenclass:: spead2::send::inproc_stream
   :members: inproc_stream, get_queue

Receiving
---------

.. doxygenclass:: spead2::recv::inproc_reader
   :members: inproc_reader
